bl_info = {
    "name": "BPM Markers",
    "blender": (2, 80, 0),
    "category": "System",
}

import bpy

class BPM_Markers(bpy.types.Operator):
    """BPM Markers"""
    bl_idname = "system.bpm_markers"
    bl_label = "BPM Markers"
    bl_options = {'REGISTER', 'UNDO'}

    bpy.types.Scene.bpm = bpy.props.FloatProperty(name="BPM", default=120, min=1, max=1000)

    def execute(self, context):
        scene = context.scene

        fps = scene.render.fps
        fpb = 60 * fps / scene.bpm

        frame = scene.frame_start
        scene.timeline_markers.clear()
        while frame < scene.frame_end:
            scene.timeline_markers.new(name="|", frame=frame)
            frame += fpb

        return {'FINISHED'}

def bpmButton(self, context):
    scene = context.scene
    layout = self.layout

    layout.prop(scene, "bpm", text="")
    icon = "TRIA_RIGHT_BAR"
    layout.operator("system.bpm_markers", text="Set the BPM to " + str("%.2f" % scene.bpm), icon=icon)

def register():
    bpy.utils.register_class(BPM_Markers)
    bpy.types.TIME_MT_editor_menus.append(bpmButton)

def unregister():
    bpy.utils.unregister_class(BPM_Markers)
    bpy.types.TIME_MT_editor_menus.remove(bpmButton)

if __name__ == "__main__":
    register()